use crate::error::CnfError;
use std::path::Path;

const CONTAINER_ENV: &str = "/run/.containerenv";

pub fn detect() -> bool {
    Path::new(CONTAINER_ENV).exists()
}

pub fn run(_args: &[&str]) -> Result<(), CnfError> {
    Err(CnfError::NotImplemented("Environment Container".into()))
}
